@@ -5,7 +5,6 @@ import (
 	"errors"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"os"
 	"path"
 	"path/filepath"
@@ -34,7 +33,7 @@ func Run() (err error) {
 	app := cli.NewApp()
 	app.Name = "croc"
 	if Version == "" {
-		Version = "v9.4.2-49f50a5"
+		Version = "v9.5.0-f210ef8"
 	}
 	app.Version = Version
 	app.Compiled = time.Now()
@@ -102,6 +101,7 @@ func Run() (err error) {
 		&cli.StringFlag{Name: "out", Value: ".", Usage: "specify an output folder to receive the file"},
 		&cli.StringFlag{Name: "pass", Value: models.DEFAULT_PASSPHRASE, Usage: "password for the relay", EnvVars: []string{"CROC_PASS"}},
 		&cli.StringFlag{Name: "socks5", Value: "", Usage: "add a socks5 proxy", EnvVars: []string{"SOCKS5_PROXY"}},
+		&cli.StringFlag{Name: "throttleUpload", Value: "", Usage: "Throttle the upload speed e.g. 500k"},
 	}
 	app.EnableBashCompletion = true
 	app.HideHelp = false
@@ -177,7 +177,7 @@ func getConfigFile() string {
 
 func determinePass(c *cli.Context) (pass string) {
 	pass = c.String("pass")
-	b, err := ioutil.ReadFile(pass)
+	b, err := os.ReadFile(pass)
 	if err == nil {
 		pass = strings.TrimSpace(string(b))
 	}
@@ -207,13 +207,14 @@ func send(c *cli.Context) (err error) {
 		Overwrite:      c.Bool("overwrite"),
 		Curve:          c.String("curve"),
 		HashAlgorithm:  c.String("hash"),
+		ThrottleUpload: c.String("throttleUpload"),
 	}
 	if crocOptions.RelayAddress != models.DEFAULT_RELAY {
 		crocOptions.RelayAddress6 = ""
 	} else if crocOptions.RelayAddress6 != models.DEFAULT_RELAY6 {
 		crocOptions.RelayAddress = ""
 	}
-	b, errOpen := ioutil.ReadFile(getConfigFile())
+	b, errOpen := os.ReadFile(getConfigFile())
 	if errOpen == nil && !c.Bool("remember") {
 		var rememberedOptions croc.Options
 		err = json.Unmarshal(b, &rememberedOptions)
@@ -310,7 +311,7 @@ func send(c *cli.Context) (err error) {
 }
 
 func getStdin() (fnames []string, err error) {
-	f, err := ioutil.TempFile(".", "croc-stdin-")
+	f, err := os.CreateTemp(".", "croc-stdin-")
 	if err != nil {
 		return
 	}
@@ -327,7 +328,7 @@ func getStdin() (fnames []string, err error) {
 }
 
 func makeTempFileWithString(s string) (fnames []string, err error) {
-	f, err := ioutil.TempFile(".", "croc-stdin-")
+	f, err := os.CreateTemp(".", "croc-stdin-")
 	if err != nil {
 		return
 	}
@@ -401,7 +402,7 @@ func saveConfig(c *cli.Context, crocOptions croc.Options) {
 			log.Error(err)
 			return
 		}
-		err = ioutil.WriteFile(configFile, bConfig, 0644)
+		err = os.WriteFile(configFile, bConfig, 0644)
 		if err != nil {
 			log.Error(err)
 			return
@@ -451,7 +452,7 @@ func receive(c *cli.Context) (err error) {
 		return
 	}
 	configFile = path.Join(configFile, "receive.json")
-	b, errOpen := ioutil.ReadFile(configFile)
+	b, errOpen := os.ReadFile(configFile)
 	if errOpen == nil && !c.Bool("remember") {
 		var rememberedOptions croc.Options
 		err = json.Unmarshal(b, &rememberedOptions)
@@ -459,7 +460,7 @@ func receive(c *cli.Context) (err error) {
 			log.Error(err)
 			return
 		}
-		// update anything that isn't expliciGlobalIsSettly set
+		// update anything that isn't explicitly Globally set
 		if !c.IsSet("relay") && rememberedOptions.RelayAddress != "" {
 			crocOptions.RelayAddress = rememberedOptions.RelayAddress
 		}
@@ -509,7 +510,7 @@ func receive(c *cli.Context) (err error) {
 			log.Error(err)
 			return
 		}
-		err = ioutil.WriteFile(configFile, bConfig, 0644)
+		err = os.WriteFile(configFile, bConfig, 0644)
 		if err != nil {
 			log.Error(err)
 			return
