@@ -1,7 +1,6 @@
 package croc
 
 import (
-	"io/ioutil"
 	"os"
 	"sync"
 	"testing"
@@ -15,11 +14,11 @@ import (
 func init() {
 	log.SetLevel("trace")
 
-	go tcp.Run("debug", "localhost", "8081", "pass123", "8082,8083,8084,8085")
-	go tcp.Run("debug", "localhost", "8082", "pass123")
-	go tcp.Run("debug", "localhost", "8083", "pass123")
-	go tcp.Run("debug", "localhost", "8084", "pass123")
-	go tcp.Run("debug", "localhost", "8085", "pass123")
+	go tcp.Run("debug", "localhost", "8281", "pass123", "8282,8283,8284,8285")
+	go tcp.Run("debug", "localhost", "8282", "pass123")
+	go tcp.Run("debug", "localhost", "8283", "pass123")
+	go tcp.Run("debug", "localhost", "8284", "pass123")
+	go tcp.Run("debug", "localhost", "8285", "pass123")
 	time.Sleep(1 * time.Second)
 }
 
@@ -31,8 +30,8 @@ func TestCrocReadme(t *testing.T) {
 		IsSender:      true,
 		SharedSecret:  "8123-testingthecroc",
 		Debug:         true,
-		RelayAddress:  "localhost:8081",
-		RelayPorts:    []string{"8081"},
+		RelayAddress:  "localhost:8281",
+		RelayPorts:    []string{"8281"},
 		RelayPassword: "pass123",
 		Stdout:        false,
 		NoPrompt:      true,
@@ -49,7 +48,7 @@ func TestCrocReadme(t *testing.T) {
 		IsSender:      false,
 		SharedSecret:  "8123-testingthecroc",
 		Debug:         true,
-		RelayAddress:  "localhost:8081",
+		RelayAddress:  "localhost:8281",
 		RelayPassword: "pass123",
 		Stdout:        false,
 		NoPrompt:      true,
@@ -153,7 +152,7 @@ func TestCrocLocal(t *testing.T) {
 
 func TestCrocError(t *testing.T) {
 	content := []byte("temporary file's content")
-	tmpfile, err := ioutil.TempFile("", "example")
+	tmpfile, err := os.CreateTemp("", "example")
 	if err != nil {
 		panic(err)
 	}
